##
##  libgsf.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major   1.14
%define       V_minor   52

#   package information
Name:         libgsf
Summary:      GNOME Structured Formats Library
URL:          http://www.gnome.org/
Vendor:       Jody Goldberg
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Libraries
License:      LGPL
Version:      %{V_major}.%{V_minor}
Release:      20240206

#   list of sources
Source0:      http://ftp.gnome.org/pub/GNOME/sources/libgsf/%{V_major}/libgsf-%{version}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl, perl-xml, pkgconfig, make, intltool
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  glib, libxml, zlib, bzip2
PreReq:       glib, libxml, zlib, bzip2

%description
    Libgsf is the GNOME library for working with structured file
    formats.

%track
    prog libgsf:major = {
        version   = %{V_major}
        url       = http://ftp.gnome.org/pub/GNOME/sources/libgsf/
        regex     = (\d+\.\d+)/
    }
    prog libgsf:full = {
        version   = %{version}
        url       = http://ftp.gnome.org/pub/GNOME/sources/libgsf/%{V_major}/
        regex     = libgsf-(__VER__)\.tar\.xz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    GREP="grep" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --with-zlib=%{l_prefix} \
        --with-bz2 \
        --without-gdk-pixbuf \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/gtk-doc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/locale
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/man
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/include/libgsf-1/gsf-gnome
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/include/libgsf-1/gsf-win32
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

